Documentation
¶
Index ¶
- type DB
- func (d *DB) AlreadyMigrated(sourceFolder string, sourceUID, uidValidity uint32) (bool, error)
- func (d *DB) Close() error
- func (d *DB) MarkDeleted(sourceFolder string, sourceUID, uidValidity uint32) error
- func (d *DB) RecordMigration(sourceFolder string, sourceUID, uidValidity uint32, destFolder string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DB ¶
type DB struct {
// contains filtered or unexported fields
}
DB wraps the SQLite state database.
func (*DB) AlreadyMigrated ¶
AlreadyMigrated returns true if this source message has been successfully copied before.
func (*DB) MarkDeleted ¶
MarkDeleted updates the record to indicate the source message was expunged.
Click to show internal directories.
Click to hide internal directories.